aboutsummaryrefslogtreecommitdiff
path: root/backends/fs/symbian
diff options
context:
space:
mode:
Diffstat (limited to 'backends/fs/symbian')
-rw-r--r--backends/fs/symbian/symbian-fs-factory.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/backends/fs/symbian/symbian-fs-factory.h b/backends/fs/symbian/symbian-fs-factory.h
index 4b663fd6b9..502fba2930 100644
--- a/backends/fs/symbian/symbian-fs-factory.h
+++ b/backends/fs/symbian/symbian-fs-factory.h
@@ -26,14 +26,14 @@
#define SYMBIAN_FILESYSTEM_FACTORY_H
#include "common/singleton.h"
-#include "backends/fs/abstract-fs-factory.h"
+#include "backends/fs/fs-factory.h"
/**
* Creates SymbianFilesystemNode objects.
*
* Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
*/
-class SymbianFilesystemFactory : public AbstractFilesystemFactory, public Common::Singleton<SymbianFilesystemFactory> {
+class SymbianFilesystemFactory : public FilesystemFactory, public Common::Singleton<SymbianFilesystemFactory> {
public:
typedef Common::String String;
@@ -26,14 +26,14 @@
* Creates SymbianFilesystemNode objects.
*
- * Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
+ * Parts of this class are documented in the base interface class, FilesystemFactory.
*/